# API Reference

| Namespace | Description |
| :--- | :--- |
| **[pqlattice](pqlattice.md)** | main module, exposes all other submodules |
| **[integer](integer.md)** | basic integer funcstion adn modular arithmetic operations |
| **[lattice](lattice.md)** | lattice reductions, embeddings and and general lattice functions |
| **[linalg](linalg.md)** | linear algebra functions for integer matrices and modular integer matrices |
| **[polynomial](polynomial.md)** | implemenation  |
| **[random](random.md)** | random samples i.a. discrete gaussian |
| **[typing](typing.md)** | declaration of type aliases for matrices and vectors |
